<?php
/* (c) 2001 Marco Pratesi <pratesi@telug.it> */
include ("application.inc.php");
require ("$CFG->libdir" . "/referer_and_query.inc.php");
if ($SESSION["frames_used"]) {	// are you joking ? :)
	$SESSION["frames_used"] = 0;
	header("Location: $CFG->wwwroot" . "/index.php");
}
$SESSION["frames_used"] = 1;
$SESSION["catbrowser_target"] = "bodyframe";
//header("Location: $REFERER_AND_QUERY");
?>

<html>
<frameset cols="180,*" framespacing=0 frameborder=no border=0>
<frame name="categories" src="shopping/navigation.php" target="bodyframe">
<frame name="bodyframe" src="<?php echo $REFERER_AND_QUERY; ?>">
</frameset>
</html>
